server_client_20150129_153254

### config1 : test_client_isolation

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.26198101044 sec | 5.3530061245 sec

Error message: Did not properly handle faulty client

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.88 | 0.33 | 0.26 | 0.29 | 0.35 | 0.41 | 0.44 | 0.66 | 0.079
qps | 388.00 | 217.50 | 47.00 | 217.50 | 302.75 | 353.90 | 370.95 | 384.59 | 170.50

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.294
server1-perf | latency | mean lt 0.33 | 0.326188505747
server1-perf | qps | mean lt 7.0 | 217.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None